@@ -4,8 +4,6 @@
 
 # reticulate::py_module_available("sympy")
 # reticulate::miniconda_update()
-
-
 # reticulate::conda_remove('r-reticulate')
 # reticulate::use_python('/usr/bin/python3')
 # reticulate::conda_create('r-reticulate')
@@ -19,7 +17,6 @@ pkg_globals$internal_sympy <- NULL
 pkg_globals$internal_sympy_version <- NULL
 pkg_globals$internal_globals_length <- NULL
 
-
 define_printers <- function() {
   fl <- system.file("define_printers.py", package = "caracas")
   reticulate::py_run_file(fl)
@@ -139,9 +136,9 @@ get_py <- function() {
 
 #' Access 'SymPy' directly
 #' 
-#' Get the 'SymPy' object.  
-#' Note that it gives you extra responsibilities
-#' when you choose to access the 'SymPy' object directly.
+#' Get the 'SymPy' object. Note that it gives you extra
+#' responsibilities when you choose to access the 'SymPy' object
+#' directly.
 #'
 #' @return The 'SymPy' object with direct access to the library.
 #'
@@ -165,13 +162,13 @@ get_sympy <- function() {
 #' Install the 'SymPy' Python package into a 
 #' virtual environment or Conda environment.
 #' 
-#' @param method Installation method. 
-#' By default, "auto" automatically finds a method that will work 
-#' in the local environment. 
-#' Change the default to force a specific installation method. 
-#' Note that the "virtualenv" method is not available on Windows.
-#' @param conda Path to conda executable (or "auto" to find conda 
-#' using the PATH and other conventional install locations).
+#' @param method Installation method.  By default, "auto"
+#'     automatically finds a method that will work in the local
+#'     environment.  Change the default to force a specific
+#'     installation method.  Note that the "virtualenv" method is not
+#'     available on Windows.
+#' @param conda Path to conda executable (or "auto" to find conda
+#'     using the PATH and other conventional install locations).
 #' 
 #' @return None
 #' 
@@ -182,7 +179,6 @@ get_sympy <- function() {
 install_sympy <- function(method = "auto", conda = "auto") {
   reticulate::py_install("sympy", method = method, conda = conda)
   message("Please check output above to verify that 'SymPy' was installed correctly. ", 
-          "If so, please have fun!", 
           "\n\nIf for some reason it does not work, try updating conda\n", 
           "with this R command:\nreticulate::miniconda_update()")
   return(invisible(NULL))
